@@ -115,7 +115,7 @@ class P100():
 			}
 		}
 
-		r = requests.post(URL, json=Payload)
+		r = requests.post(URL, json=Payload, timeout=2)
 
 		encryptedKey = r.json()["result"]["key"]
 		self.tpLinkCipher = self.decode_handshake_key(encryptedKey)
@@ -151,7 +151,7 @@ class P100():
 			}
 		}
 
-		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers)
+		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers, timeout=2)
 
 		decryptedResponse = self.tpLinkCipher.decrypt(r.json()["result"]["response"])
 
@@ -186,39 +186,7 @@ class P100():
 			}
 		}
 
-		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers)
-
-		decryptedResponse = self.tpLinkCipher.decrypt(r.json()["result"]["response"])
-
-		if ast.literal_eval(decryptedResponse)["error_code"] != 0:
-			errorCode = ast.literal_eval(decryptedResponse)["error_code"]
-			errorMessage = self.errorCodes[str(errorCode)]
-			raise Exception(f"Error Code: {errorCode}, {errorMessage}")
-
-	def setBrightness(self, brightness):
-		URL = f"http://{self.ipAddress}/app?token={self.token}"
-		Payload = {
-			"method": "set_device_info",
-			"params":{
-				"brightness": brightness
-			},
-			"requestTimeMils": int(round(time.time() * 1000)),
-		}
-
-		headers = {
-			"Cookie": self.cookie
-		}
-
-		EncryptedPayload = self.tpLinkCipher.encrypt(json.dumps(Payload))
-
-		SecurePassthroughPayload = {
-			"method": "securePassthrough",
-			"params":{
-				"request": EncryptedPayload
-			}
-		}
-
-		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers)
+		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers, timeout=2)
 
 		decryptedResponse = self.tpLinkCipher.decrypt(r.json()["result"]["response"])
 
@@ -251,7 +219,7 @@ class P100():
 			}
 		}
 
-		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers)
+		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers, timeout=2)
 
 		decryptedResponse = self.tpLinkCipher.decrypt(r.json()["result"]["response"])
 
@@ -290,8 +258,6 @@ class P100():
 		self.login()
 		data = self.getDeviceInfo()
 
-		data = json.loads(data)
-
 		if data["error_code"] != 0:
 			errorCode = ast.literal_eval(decryptedResponse)["error_code"]
 			errorMessage = self.errorCodes[str(errorCode)]
